==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/13/13ee7777ae7b31b30d78a4c52679a642.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Translations/en_US/flashes.ini */
class __TwigTemplate_2cd1efc2846eae59451d486ed5e4ef19 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "mautic.core.action.entity.unlocked=\"%name% has been unlocked and is now available for editing.\"
mautic.core.could.not.set.language=\"Could not set the preferred language. Using default language instead.\"
mautic.core.error.accessdenied=\"You do not have access to the requested area/action.\"
mautic.core.error.badrequest=\"This is a bad request.\"
mautic.core.error.locked=\"%name% is currently checked out by <a href='%contactUrl%'>%user%</a> (checked out on %date% at %time%). %override%\"
mautic.core.error.not.valid=\"Form is not valid. Fill in all required fields.\"
mautic.core.error.notfound=\"Item was not found.\"
mautic.core.error.delete.error=\"Item could not be deleted. %error%\"
mautic.core.error.max.field=\"You have reached the limit of custom fields allowed by your database.\"
mautic.core.notice.batch_deleted=\"%count% items deleted\"
mautic.core.notice.created=\"<a href='%url%' data-toggle='ajax' data-menu-link='%menu_link%'><strong>%name%</strong></a> has been created!\"
mautic.core.notice.deleted=\"<strong>%name%</strong> has been deleted!\"
mautic.core.notice.updated=\"<a href='%url%' data-toggle='ajax' data-menu-link='%menu_link%'><strong>%name%</strong></a> has been updated!\"
mautic.core.notice.used.field=\"Field \"%name%\" (#%id%) cannot be deleted because it's used in the following Segment(s): %segments%.\"
mautic.core.notice.used.fields=\"Field(s) \"%fields%\" cannot be deleted because they are used in the following Segment(s): %segments%.\"
mautic.core.notice.campaign.unpublished.email=\"Email <a href='%url%' data-toggle='ajax' data-menu-link='%menu_link%'><strong>%name%</strong></a> used in campaign is not published.\"
mautic.core.language.helper.error.fetching.package=\"An error occurred while downloading the language package.\"
mautic.core.language.helper.error.follow.redirects=\"Whoops, either safe_mode or open_basedir is turned on. Download the language from <a href='%url%'>here</a>. Unzip and upload it to the /translations directory.\"
mautic.core.language.helper.invalid.language=\"Requested language '%language%' does not exist among the available Mautic languages. The language was reset to the default one.\"
mautic.core.language.helper.error.on.language.server.side=\"The language server responded with HTTP code %code%. It is probably temporarily unavailable. Try to change the language later. The language was reset to the default one for now.\"
mautic.core.language.helper.error.fetching.package.exception=\"A problem ocurred when requesting the language package: %exception%. The language was reset to the default one for now.\"
mautic.core.ziparchive.not.installed=\"The ZIP package cannot be unzipped. The php-zip module is missing. Contact your server admin.\"
mautic.core.theme.error.notfound=\"Theme %theme% not found.\"
mautic.core.permission.issue=\"There was a file permission issue during this task. Contact your sysadmin to fix the permissions.\"
mautic.core.theme.installed=\"Theme <strong>%name%</strong> has been installed!\"
mautic.core.theme.cannot.be.removed=\"%theme% is the default theme and therefore cannot be removed.\"
mautic.core.error.entity.not.found=\"%entity% ID %id% not found\"
mautic.core.error.csrf=\"CSRF token error. Try to refresh the page and try again.\"
mautic.core.error.ids.missing=\"No IDs were provided.\"
mautic.core.error.access.denied=\"Access denied\"
mautic.core.theme.visibility.changed=\"Theme <strong>%theme%</strong> visibility changed!\"
mautic.core.theme.cannot.change.visibility=\"%theme% is the not a default theme and therefore cannot change it's visibility.\"
mautic.core.theme.visibility.error=\"Could not change theme visibility. Error: %error%\"
mautic.core.theme.notice.batch_deleted=\"%count% themes have been deleted!\"
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Translations/en_US/flashes.ini";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Translations/en_US/flashes.ini", "/var/www/mautic-ktn/app/bundles/CoreBundle/Translations/en_US/flashes.ini");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/13/13ee7777ae7b31b30d78a4c52679a642.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Translations/en_US/flashes.ini */
class __TwigTemplate_2cd1efc2846eae59451d486ed5e4ef19 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "mautic.core.action.entity.unlocked=\"%name% has been unlocked and is now available for editing.\"
mautic.core.could.not.set.language=\"Could not set the preferred language. Using default language instead.\"
mautic.core.error.accessdenied=\"You do not have access to the requested area/action.\"
mautic.core.error.badrequest=\"This is a bad request.\"
mautic.core.error.locked=\"%name% is currently checked out by <a href='%contactUrl%'>%user%</a> (checked out on %date% at %time%). %override%\"
mautic.core.error.not.valid=\"Form is not valid. Fill in all required fields.\"
mautic.core.error.notfound=\"Item was not found.\"
mautic.core.error.delete.error=\"Item could not be deleted. %error%\"
mautic.core.error.max.field=\"You have reached the limit of custom fields allowed by your database.\"
mautic.core.notice.batch_deleted=\"%count% items deleted\"
mautic.core.notice.created=\"<a href='%url%' data-toggle='ajax' data-menu-link='%menu_link%'><strong>%name%</strong></a> has been created!\"
mautic.core.notice.deleted=\"<strong>%name%</strong> has been deleted!\"
mautic.core.notice.updated=\"<a href='%url%' data-toggle='ajax' data-menu-link='%menu_link%'><strong>%name%</strong></a> has been updated!\"
mautic.core.notice.used.field=\"Field \"%name%\" (#%id%) cannot be deleted because it's used in the following Segment(s): %segments%.\"
mautic.core.notice.used.fields=\"Field(s) \"%fields%\" cannot be deleted because they are used in the following Segment(s): %segments%.\"
mautic.core.notice.campaign.unpublished.email=\"Email <a href='%url%' data-toggle='ajax' data-menu-link='%menu_link%'><strong>%name%</strong></a> used in campaign is not published.\"
mautic.core.language.helper.error.fetching.package=\"An error occurred while downloading the language package.\"
mautic.core.language.helper.error.follow.redirects=\"Whoops, either safe_mode or open_basedir is turned on. Download the language from <a href='%url%'>here</a>. Unzip and upload it to the /translations directory.\"
mautic.core.language.helper.invalid.language=\"Requested language '%language%' does not exist among the available Mautic languages. The language was reset to the default one.\"
mautic.core.language.helper.error.on.language.server.side=\"The language server responded with HTTP code %code%. It is probably temporarily unavailable. Try to change the language later. The language was reset to the default one for now.\"
mautic.core.language.helper.error.fetching.package.exception=\"A problem ocurred when requesting the language package: %exception%. The language was reset to the default one for now.\"
mautic.core.ziparchive.not.installed=\"The ZIP package cannot be unzipped. The php-zip module is missing. Contact your server admin.\"
mautic.core.theme.error.notfound=\"Theme %theme% not found.\"
mautic.core.permission.issue=\"There was a file permission issue during this task. Contact your sysadmin to fix the permissions.\"
mautic.core.theme.installed=\"Theme <strong>%name%</strong> has been installed!\"
mautic.core.theme.cannot.be.removed=\"%theme% is the default theme and therefore cannot be removed.\"
mautic.core.error.entity.not.found=\"%entity% ID %id% not found\"
mautic.core.error.csrf=\"CSRF token error. Try to refresh the page and try again.\"
mautic.core.error.ids.missing=\"No IDs were provided.\"
mautic.core.error.access.denied=\"Access denied\"
mautic.core.theme.visibility.changed=\"Theme <strong>%theme%</strong> visibility changed!\"
mautic.core.theme.cannot.change.visibility=\"%theme% is the not a default theme and therefore cannot change it's visibility.\"
mautic.core.theme.visibility.error=\"Could not change theme visibility. Error: %error%\"
mautic.core.theme.notice.batch_deleted=\"%count% themes have been deleted!\"
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Translations/en_US/flashes.ini";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Translations/en_US/flashes.ini", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Translations/en_US/flashes.ini");
    }
}
